# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/clickhouse/v1/user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/clickhouse/v1/user.proto',
  package='yandex.cloud.mdb.clickhouse.v1',
  syntax='proto3',
  serialized_options=b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)yandex/cloud/mdb/clickhouse/v1/user.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xe4\x01\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12?\n\x0bpermissions\x18\x03 \x03(\x0b\x32*.yandex.cloud.mdb.clickhouse.v1.Permission\x12>\n\x08settings\x18\x04 \x01(\x0b\x32,.yandex.cloud.mdb.clickhouse.v1.UserSettings\x12\x39\n\x06quotas\x18\x05 \x03(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.UserQuota\")\n\nPermission\x12\x15\n\rdatabase_name\x18\x01 \x01(\tJ\x04\x08\x02\x10\x03\"\x94\x02\n\x08UserSpec\x12+\n\x04name\x18\x01 \x01(\tB\x1d\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\r[a-zA-Z0-9_]*\x12\x1f\n\x08password\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x38-128\x12?\n\x0bpermissions\x18\x03 \x03(\x0b\x32*.yandex.cloud.mdb.clickhouse.v1.Permission\x12>\n\x08settings\x18\x04 \x01(\x0b\x32,.yandex.cloud.mdb.clickhouse.v1.UserSettings\x12\x39\n\x06quotas\x18\x05 \x03(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.UserQuota\"\xcb:\n\x0cUserSettings\x12\x36\n\x08readonly\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03\x30-2\x12-\n\tallow_ddl\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12;\n\rinsert_quorum\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12<\n\x0f\x63onnect_timeout\x18\' \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12<\n\x0freceive_timeout\x18( \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x39\n\x0csend_timeout\x18) \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x46\n\x15insert_quorum_timeout\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06>=1000\x12\x41\n\x1dselect_sequential_consistency\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12Z\n)max_replica_delay_for_distributed_queries\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06>=1000\x12V\n2fallback_to_stale_replicas_for_distributed_queries\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12O\n!replication_alter_partitions_sync\x18* \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03\x30-2\x12\x65\n\x18\x64istributed_product_mode\x18+ \x01(\x0e\x32\x43.yandex.cloud.mdb.clickhouse.v1.UserSettings.DistributedProductMode\x12L\n(distributed_aggregation_memory_efficient\x18H \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x1c\x64istributed_ddl_task_timeout\x18I \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x17skip_unavailable_shards\x18Q \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x07\x63ompile\x18, \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x14min_count_to_compile\x18- \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x37\n\x13\x63ompile_expressions\x18. \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12M\n\x1fmin_count_to_compile_expression\x18/ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12;\n\x0emax_block_size\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12H\n\x1amin_insert_block_size_rows\x18\x30 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12I\n\x1bmin_insert_block_size_bytes\x18\x31 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x42\n\x15max_insert_block_size\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12H\n\x1amin_bytes_to_use_direct_io\x18\x32 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12:\n\x16use_uncompressed_cache\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12M\n merge_tree_max_rows_to_use_cache\x18\x34 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12N\n!merge_tree_max_bytes_to_use_cache\x18\x35 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12T\n\'merge_tree_min_rows_for_concurrent_read\x18\x36 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12U\n(merge_tree_min_bytes_for_concurrent_read\x18\x37 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12G\n\"max_bytes_before_external_group_by\x18J \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x43\n\x1emax_bytes_before_external_sort\x18K \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x41\n\x1cgroup_by_two_level_threshold\x18L \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12G\n\"group_by_two_level_threshold_bytes\x18M \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x08priority\x18\x38 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x38\n\x0bmax_threads\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12>\n\x10max_memory_usage\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12G\n\x19max_memory_usage_for_user\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12:\n\x15max_network_bandwidth\x18\x39 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x43\n\x1emax_network_bandwidth_for_user\x18: \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x13\x66orce_index_by_date\x18; \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x11\x66orce_primary_key\x18< \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12>\n\x10max_rows_to_read\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12?\n\x11max_bytes_to_read\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12U\n\x12read_overflow_mode\x18\x0f \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12\x42\n\x14max_rows_to_group_by\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12`\n\x16group_by_overflow_mode\x18\x11 \x01(\x0e\x32@.yandex.cloud.mdb.clickhouse.v1.UserSettings.GroupByOverflowMode\x12>\n\x10max_rows_to_sort\x18\x12 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12?\n\x11max_bytes_to_sort\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12U\n\x12sort_overflow_mode\x18\x14 \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12=\n\x0fmax_result_rows\x18\x15 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12>\n\x10max_result_bytes\x18\x16 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12W\n\x14result_overflow_mode\x18\x17 \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12\x42\n\x14max_rows_in_distinct\x18\x18 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x43\n\x15max_bytes_in_distinct\x18\x19 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12Y\n\x16\x64istinct_overflow_mode\x18\x1a \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12\x42\n\x14max_rows_to_transfer\x18\x1b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x43\n\x15max_bytes_to_transfer\x18\x1c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12Y\n\x16transfer_overflow_mode\x18\x1d \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12@\n\x12max_execution_time\x18\x1e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12X\n\x15timeout_overflow_mode\x18\x1f \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12=\n\x0fmax_rows_in_set\x18W \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12>\n\x10max_bytes_in_set\x18X \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12T\n\x11set_overflow_mode\x18Y \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12>\n\x10max_rows_in_join\x18Z \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12?\n\x11max_bytes_in_join\x18[ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12U\n\x12join_overflow_mode\x18\\ \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12\x41\n\x13max_columns_to_read\x18  \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x43\n\x15max_temporary_columns\x18! \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12M\n\x1fmax_temporary_non_const_columns\x18\" \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12;\n\x0emax_query_size\x18# \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12:\n\rmax_ast_depth\x18$ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12=\n\x10max_ast_elements\x18% \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x46\n\x19max_expanded_ast_elements\x18& \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x41\n\x13min_execution_speed\x18T \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12G\n\x19min_execution_speed_bytes\x18U \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12o\n\x1d\x63ount_distinct_implementation\x18V \x01(\x0e\x32H.yandex.cloud.mdb.clickhouse.v1.UserSettings.CountDistinctImplementation\x12M\n)input_format_values_interpret_expressions\x18= \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12L\n(input_format_defaults_for_omitted_fields\x18> \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12p\n\'output_format_json_quote_64bit_integers\x18? \x01(\x0b\x32\x1a.google.protobuf.BoolValueR#outputFormatJsonQuote_64bitIntegers\x12\x46\n\"output_format_json_quote_denormals\x18@ \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12J\n&low_cardinality_allow_in_native_format\x18N \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12M\n)empty_result_for_aggregation_by_empty_set\x18O \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x1ejoined_subquery_requires_alias\x18] \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0ejoin_use_nulls\x18^ \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x11transform_null_in\x18_ \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x17http_connection_timeout\x18\x41 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14http_receive_timeout\x18\x42 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11http_send_timeout\x18\x43 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x17\x65nable_http_compression\x18\x44 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x1dsend_progress_in_http_headers\x18\x45 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x43\n\x1ehttp_headers_progress_interval\x18\x46 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x14\x61\x64\x64_http_cors_header\x18G \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12J\n\nquota_mode\x18P \x01(\x0e\x32\x36.yandex.cloud.mdb.clickhouse.v1.UserSettings.QuotaMode\"_\n\x0cOverflowMode\x12\x1d\n\x19OVERFLOW_MODE_UNSPECIFIED\x10\x00\x12\x17\n\x13OVERFLOW_MODE_THROW\x10\x01\x12\x17\n\x13OVERFLOW_MODE_BREAK\x10\x02\"\xa1\x01\n\x13GroupByOverflowMode\x12&\n\"GROUP_BY_OVERFLOW_MODE_UNSPECIFIED\x10\x00\x12 \n\x1cGROUP_BY_OVERFLOW_MODE_THROW\x10\x01\x12 \n\x1cGROUP_BY_OVERFLOW_MODE_BREAK\x10\x02\x12\x1e\n\x1aGROUP_BY_OVERFLOW_MODE_ANY\x10\x03\"\xd2\x01\n\x16\x44istributedProductMode\x12(\n$DISTRIBUTED_PRODUCT_MODE_UNSPECIFIED\x10\x00\x12!\n\x1d\x44ISTRIBUTED_PRODUCT_MODE_DENY\x10\x01\x12\"\n\x1e\x44ISTRIBUTED_PRODUCT_MODE_LOCAL\x10\x02\x12#\n\x1f\x44ISTRIBUTED_PRODUCT_MODE_GLOBAL\x10\x03\x12\"\n\x1e\x44ISTRIBUTED_PRODUCT_MODE_ALLOW\x10\x04\"q\n\tQuotaMode\x12\x1a\n\x16QUOTA_MODE_UNSPECIFIED\x10\x00\x12\x16\n\x12QUOTA_MODE_DEFAULT\x10\x01\x12\x14\n\x10QUOTA_MODE_KEYED\x10\x02\x12\x1a\n\x16QUOTA_MODE_KEYED_BY_IP\x10\x03\"\xb6\x02\n\x1b\x43ountDistinctImplementation\x12-\n)COUNT_DISTINCT_IMPLEMENTATION_UNSPECIFIED\x10\x00\x12&\n\"COUNT_DISTINCT_IMPLEMENTATION_UNIQ\x10\x01\x12/\n+COUNT_DISTINCT_IMPLEMENTATION_UNIQ_COMBINED\x10\x02\x12\x32\n.COUNT_DISTINCT_IMPLEMENTATION_UNIQ_COMBINED_64\x10\x03\x12-\n)COUNT_DISTINCT_IMPLEMENTATION_UNIQ_HLL_12\x10\x04\x12,\n(COUNT_DISTINCT_IMPLEMENTATION_UNIQ_EXACT\x10\x05\"\xee\x02\n\tUserQuota\x12\x42\n\x11interval_duration\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06>=1000\x12\x35\n\x07queries\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x34\n\x06\x65rrors\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x39\n\x0bresult_rows\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x37\n\tread_rows\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12<\n\x0e\x65xecution_time\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0Bs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])



_USERSETTINGS_OVERFLOWMODE = _descriptor.EnumDescriptor(
  name='OverflowMode',
  full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OVERFLOW_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OVERFLOW_MODE_THROW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OVERFLOW_MODE_BREAK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7293,
  serialized_end=7388,
)
_sym_db.RegisterEnumDescriptor(_USERSETTINGS_OVERFLOWMODE)

_USERSETTINGS_GROUPBYOVERFLOWMODE = _descriptor.EnumDescriptor(
  name='GroupByOverflowMode',
  full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.GroupByOverflowMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GROUP_BY_OVERFLOW_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUP_BY_OVERFLOW_MODE_THROW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUP_BY_OVERFLOW_MODE_BREAK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUP_BY_OVERFLOW_MODE_ANY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7391,
  serialized_end=7552,
)
_sym_db.RegisterEnumDescriptor(_USERSETTINGS_GROUPBYOVERFLOWMODE)

_USERSETTINGS_DISTRIBUTEDPRODUCTMODE = _descriptor.EnumDescriptor(
  name='DistributedProductMode',
  full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.DistributedProductMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DISTRIBUTED_PRODUCT_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISTRIBUTED_PRODUCT_MODE_DENY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISTRIBUTED_PRODUCT_MODE_LOCAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISTRIBUTED_PRODUCT_MODE_GLOBAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISTRIBUTED_PRODUCT_MODE_ALLOW', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7555,
  serialized_end=7765,
)
_sym_db.RegisterEnumDescriptor(_USERSETTINGS_DISTRIBUTEDPRODUCTMODE)

_USERSETTINGS_QUOTAMODE = _descriptor.EnumDescriptor(
  name='QuotaMode',
  full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.QuotaMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='QUOTA_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUOTA_MODE_DEFAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUOTA_MODE_KEYED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUOTA_MODE_KEYED_BY_IP', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7767,
  serialized_end=7880,
)
_sym_db.RegisterEnumDescriptor(_USERSETTINGS_QUOTAMODE)

_USERSETTINGS_COUNTDISTINCTIMPLEMENTATION = _descriptor.EnumDescriptor(
  name='CountDistinctImplementation',
  full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.CountDistinctImplementation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COUNT_DISTINCT_IMPLEMENTATION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COUNT_DISTINCT_IMPLEMENTATION_UNIQ', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COUNT_DISTINCT_IMPLEMENTATION_UNIQ_COMBINED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COUNT_DISTINCT_IMPLEMENTATION_UNIQ_COMBINED_64', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COUNT_DISTINCT_IMPLEMENTATION_UNIQ_HLL_12', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COUNT_DISTINCT_IMPLEMENTATION_UNIQ_EXACT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7883,
  serialized_end=8193,
)
_sym_db.RegisterEnumDescriptor(_USERSETTINGS_COUNTDISTINCTIMPLEMENTATION)


_USER = _descriptor.Descriptor(
  name='User',
  full_name='yandex.cloud.mdb.clickhouse.v1.User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.clickhouse.v1.User.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.clickhouse.v1.User.cluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='yandex.cloud.mdb.clickhouse.v1.User.permissions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='yandex.cloud.mdb.clickhouse.v1.User.settings', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quotas', full_name='yandex.cloud.mdb.clickhouse.v1.User.quotas', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=369,
)


_PERMISSION = _descriptor.Descriptor(
  name='Permission',
  full_name='yandex.cloud.mdb.clickhouse.v1.Permission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.clickhouse.v1.Permission.database_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=412,
)


_USERSPEC = _descriptor.Descriptor(
  name='UserSpec',
  full_name='yandex.cloud.mdb.clickhouse.v1.UserSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.clickhouse.v1.UserSpec.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\r[a-zA-Z0-9_]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='yandex.cloud.mdb.clickhouse.v1.UserSpec.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\0058-128', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='yandex.cloud.mdb.clickhouse.v1.UserSpec.permissions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='yandex.cloud.mdb.clickhouse.v1.UserSpec.settings', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quotas', full_name='yandex.cloud.mdb.clickhouse.v1.UserSpec.quotas', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=415,
  serialized_end=691,
)


_USERSETTINGS = _descriptor.Descriptor(
  name='UserSettings',
  full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='readonly', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.readonly', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0030-2', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_ddl', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.allow_ddl', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='insert_quorum', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.insert_quorum', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_timeout', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.connect_timeout', index=3,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receive_timeout', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.receive_timeout', index=4,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_timeout', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.send_timeout', index=5,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='insert_quorum_timeout', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.insert_quorum_timeout', index=6,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006>=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='select_sequential_consistency', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.select_sequential_consistency', index=7,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_replica_delay_for_distributed_queries', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_replica_delay_for_distributed_queries', index=8,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006>=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fallback_to_stale_replicas_for_distributed_queries', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.fallback_to_stale_replicas_for_distributed_queries', index=9,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replication_alter_partitions_sync', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.replication_alter_partitions_sync', index=10,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0030-2', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distributed_product_mode', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.distributed_product_mode', index=11,
      number=43, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distributed_aggregation_memory_efficient', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.distributed_aggregation_memory_efficient', index=12,
      number=72, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distributed_ddl_task_timeout', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.distributed_ddl_task_timeout', index=13,
      number=73, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip_unavailable_shards', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.skip_unavailable_shards', index=14,
      number=81, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compile', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.compile', index=15,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_count_to_compile', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.min_count_to_compile', index=16,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compile_expressions', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.compile_expressions', index=17,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_count_to_compile_expression', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.min_count_to_compile_expression', index=18,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_block_size', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_block_size', index=19,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_insert_block_size_rows', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.min_insert_block_size_rows', index=20,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_insert_block_size_bytes', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.min_insert_block_size_bytes', index=21,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_insert_block_size', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_insert_block_size', index=22,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_bytes_to_use_direct_io', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.min_bytes_to_use_direct_io', index=23,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_uncompressed_cache', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.use_uncompressed_cache', index=24,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='merge_tree_max_rows_to_use_cache', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.merge_tree_max_rows_to_use_cache', index=25,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='merge_tree_max_bytes_to_use_cache', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.merge_tree_max_bytes_to_use_cache', index=26,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='merge_tree_min_rows_for_concurrent_read', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.merge_tree_min_rows_for_concurrent_read', index=27,
      number=54, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='merge_tree_min_bytes_for_concurrent_read', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.merge_tree_min_bytes_for_concurrent_read', index=28,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_bytes_before_external_group_by', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_bytes_before_external_group_by', index=29,
      number=74, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_bytes_before_external_sort', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_bytes_before_external_sort', index=30,
      number=75, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_by_two_level_threshold', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.group_by_two_level_threshold', index=31,
      number=76, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_by_two_level_threshold_bytes', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.group_by_two_level_threshold_bytes', index=32,
      number=77, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.priority', index=33,
      number=56, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_threads', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_threads', index=34,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_memory_usage', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_memory_usage', index=35,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_memory_usage_for_user', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_memory_usage_for_user', index=36,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_network_bandwidth', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_network_bandwidth', index=37,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_network_bandwidth_for_user', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_network_bandwidth_for_user', index=38,
      number=58, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force_index_by_date', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.force_index_by_date', index=39,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force_primary_key', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.force_primary_key', index=40,
      number=60, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_rows_to_read', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_rows_to_read', index=41,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_bytes_to_read', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_bytes_to_read', index=42,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_overflow_mode', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.read_overflow_mode', index=43,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_rows_to_group_by', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_rows_to_group_by', index=44,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_by_overflow_mode', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.group_by_overflow_mode', index=45,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_rows_to_sort', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_rows_to_sort', index=46,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_bytes_to_sort', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_bytes_to_sort', index=47,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_overflow_mode', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.sort_overflow_mode', index=48,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_result_rows', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_result_rows', index=49,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_result_bytes', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_result_bytes', index=50,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_overflow_mode', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.result_overflow_mode', index=51,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_rows_in_distinct', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_rows_in_distinct', index=52,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_bytes_in_distinct', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_bytes_in_distinct', index=53,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distinct_overflow_mode', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.distinct_overflow_mode', index=54,
      number=26, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_rows_to_transfer', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_rows_to_transfer', index=55,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_bytes_to_transfer', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_bytes_to_transfer', index=56,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transfer_overflow_mode', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.transfer_overflow_mode', index=57,
      number=29, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_execution_time', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_execution_time', index=58,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout_overflow_mode', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.timeout_overflow_mode', index=59,
      number=31, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_rows_in_set', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_rows_in_set', index=60,
      number=87, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_bytes_in_set', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_bytes_in_set', index=61,
      number=88, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_overflow_mode', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.set_overflow_mode', index=62,
      number=89, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_rows_in_join', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_rows_in_join', index=63,
      number=90, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_bytes_in_join', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_bytes_in_join', index=64,
      number=91, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join_overflow_mode', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.join_overflow_mode', index=65,
      number=92, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_columns_to_read', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_columns_to_read', index=66,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_temporary_columns', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_temporary_columns', index=67,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_temporary_non_const_columns', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_temporary_non_const_columns', index=68,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_query_size', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_query_size', index=69,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_ast_depth', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_ast_depth', index=70,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_ast_elements', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_ast_elements', index=71,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_expanded_ast_elements', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.max_expanded_ast_elements', index=72,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_execution_speed', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.min_execution_speed', index=73,
      number=84, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_execution_speed_bytes', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.min_execution_speed_bytes', index=74,
      number=85, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count_distinct_implementation', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.count_distinct_implementation', index=75,
      number=86, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_format_values_interpret_expressions', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.input_format_values_interpret_expressions', index=76,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_format_defaults_for_omitted_fields', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.input_format_defaults_for_omitted_fields', index=77,
      number=62, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_format_json_quote_64bit_integers', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.output_format_json_quote_64bit_integers', index=78,
      number=63, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='outputFormatJsonQuote_64bitIntegers', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_format_json_quote_denormals', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.output_format_json_quote_denormals', index=79,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low_cardinality_allow_in_native_format', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.low_cardinality_allow_in_native_format', index=80,
      number=78, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='empty_result_for_aggregation_by_empty_set', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.empty_result_for_aggregation_by_empty_set', index=81,
      number=79, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joined_subquery_requires_alias', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.joined_subquery_requires_alias', index=82,
      number=93, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join_use_nulls', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.join_use_nulls', index=83,
      number=94, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transform_null_in', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.transform_null_in', index=84,
      number=95, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_connection_timeout', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.http_connection_timeout', index=85,
      number=65, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_receive_timeout', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.http_receive_timeout', index=86,
      number=66, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_send_timeout', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.http_send_timeout', index=87,
      number=67, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_http_compression', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.enable_http_compression', index=88,
      number=68, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_progress_in_http_headers', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.send_progress_in_http_headers', index=89,
      number=69, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_headers_progress_interval', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.http_headers_progress_interval', index=90,
      number=70, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_http_cors_header', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.add_http_cors_header', index=91,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quota_mode', full_name='yandex.cloud.mdb.clickhouse.v1.UserSettings.quota_mode', index=92,
      number=80, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USERSETTINGS_OVERFLOWMODE,
    _USERSETTINGS_GROUPBYOVERFLOWMODE,
    _USERSETTINGS_DISTRIBUTEDPRODUCTMODE,
    _USERSETTINGS_QUOTAMODE,
    _USERSETTINGS_COUNTDISTINCTIMPLEMENTATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=694,
  serialized_end=8193,
)


_USERQUOTA = _descriptor.Descriptor(
  name='UserQuota',
  full_name='yandex.cloud.mdb.clickhouse.v1.UserQuota',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interval_duration', full_name='yandex.cloud.mdb.clickhouse.v1.UserQuota.interval_duration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006>=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queries', full_name='yandex.cloud.mdb.clickhouse.v1.UserQuota.queries', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errors', full_name='yandex.cloud.mdb.clickhouse.v1.UserQuota.errors', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_rows', full_name='yandex.cloud.mdb.clickhouse.v1.UserQuota.result_rows', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_rows', full_name='yandex.cloud.mdb.clickhouse.v1.UserQuota.read_rows', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_time', full_name='yandex.cloud.mdb.clickhouse.v1.UserQuota.execution_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8196,
  serialized_end=8562,
)

_USER.fields_by_name['permissions'].message_type = _PERMISSION
_USER.fields_by_name['settings'].message_type = _USERSETTINGS
_USER.fields_by_name['quotas'].message_type = _USERQUOTA
_USERSPEC.fields_by_name['permissions'].message_type = _PERMISSION
_USERSPEC.fields_by_name['settings'].message_type = _USERSETTINGS
_USERSPEC.fields_by_name['quotas'].message_type = _USERQUOTA
_USERSETTINGS.fields_by_name['readonly'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['allow_ddl'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['insert_quorum'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['connect_timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['receive_timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['send_timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['insert_quorum_timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['select_sequential_consistency'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['max_replica_delay_for_distributed_queries'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['fallback_to_stale_replicas_for_distributed_queries'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['replication_alter_partitions_sync'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['distributed_product_mode'].enum_type = _USERSETTINGS_DISTRIBUTEDPRODUCTMODE
_USERSETTINGS.fields_by_name['distributed_aggregation_memory_efficient'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['distributed_ddl_task_timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['skip_unavailable_shards'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['compile'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['min_count_to_compile'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['compile_expressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['min_count_to_compile_expression'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_block_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['min_insert_block_size_rows'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['min_insert_block_size_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_insert_block_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['min_bytes_to_use_direct_io'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['use_uncompressed_cache'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['merge_tree_max_rows_to_use_cache'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['merge_tree_max_bytes_to_use_cache'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['merge_tree_min_rows_for_concurrent_read'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['merge_tree_min_bytes_for_concurrent_read'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_bytes_before_external_group_by'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_bytes_before_external_sort'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['group_by_two_level_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['group_by_two_level_threshold_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['priority'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_threads'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_memory_usage'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_memory_usage_for_user'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_network_bandwidth'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_network_bandwidth_for_user'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['force_index_by_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['force_primary_key'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['max_rows_to_read'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_bytes_to_read'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['read_overflow_mode'].enum_type = _USERSETTINGS_OVERFLOWMODE
_USERSETTINGS.fields_by_name['max_rows_to_group_by'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['group_by_overflow_mode'].enum_type = _USERSETTINGS_GROUPBYOVERFLOWMODE
_USERSETTINGS.fields_by_name['max_rows_to_sort'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_bytes_to_sort'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['sort_overflow_mode'].enum_type = _USERSETTINGS_OVERFLOWMODE
_USERSETTINGS.fields_by_name['max_result_rows'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_result_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['result_overflow_mode'].enum_type = _USERSETTINGS_OVERFLOWMODE
_USERSETTINGS.fields_by_name['max_rows_in_distinct'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_bytes_in_distinct'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['distinct_overflow_mode'].enum_type = _USERSETTINGS_OVERFLOWMODE
_USERSETTINGS.fields_by_name['max_rows_to_transfer'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_bytes_to_transfer'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['transfer_overflow_mode'].enum_type = _USERSETTINGS_OVERFLOWMODE
_USERSETTINGS.fields_by_name['max_execution_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['timeout_overflow_mode'].enum_type = _USERSETTINGS_OVERFLOWMODE
_USERSETTINGS.fields_by_name['max_rows_in_set'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_bytes_in_set'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['set_overflow_mode'].enum_type = _USERSETTINGS_OVERFLOWMODE
_USERSETTINGS.fields_by_name['max_rows_in_join'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_bytes_in_join'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['join_overflow_mode'].enum_type = _USERSETTINGS_OVERFLOWMODE
_USERSETTINGS.fields_by_name['max_columns_to_read'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_temporary_columns'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_temporary_non_const_columns'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_query_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_ast_depth'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_ast_elements'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['max_expanded_ast_elements'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['min_execution_speed'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['min_execution_speed_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['count_distinct_implementation'].enum_type = _USERSETTINGS_COUNTDISTINCTIMPLEMENTATION
_USERSETTINGS.fields_by_name['input_format_values_interpret_expressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['input_format_defaults_for_omitted_fields'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['output_format_json_quote_64bit_integers'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['output_format_json_quote_denormals'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['low_cardinality_allow_in_native_format'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['empty_result_for_aggregation_by_empty_set'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['joined_subquery_requires_alias'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['join_use_nulls'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['transform_null_in'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['http_connection_timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['http_receive_timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['http_send_timeout'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['enable_http_compression'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['send_progress_in_http_headers'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['http_headers_progress_interval'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERSETTINGS.fields_by_name['add_http_cors_header'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_USERSETTINGS.fields_by_name['quota_mode'].enum_type = _USERSETTINGS_QUOTAMODE
_USERSETTINGS_OVERFLOWMODE.containing_type = _USERSETTINGS
_USERSETTINGS_GROUPBYOVERFLOWMODE.containing_type = _USERSETTINGS
_USERSETTINGS_DISTRIBUTEDPRODUCTMODE.containing_type = _USERSETTINGS
_USERSETTINGS_QUOTAMODE.containing_type = _USERSETTINGS
_USERSETTINGS_COUNTDISTINCTIMPLEMENTATION.containing_type = _USERSETTINGS
_USERQUOTA.fields_by_name['interval_duration'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERQUOTA.fields_by_name['queries'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERQUOTA.fields_by_name['errors'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERQUOTA.fields_by_name['result_rows'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERQUOTA.fields_by_name['read_rows'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERQUOTA.fields_by_name['execution_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
DESCRIPTOR.message_types_by_name['User'] = _USER
DESCRIPTOR.message_types_by_name['Permission'] = _PERMISSION
DESCRIPTOR.message_types_by_name['UserSpec'] = _USERSPEC
DESCRIPTOR.message_types_by_name['UserSettings'] = _USERSETTINGS
DESCRIPTOR.message_types_by_name['UserQuota'] = _USERQUOTA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.User)
  })
_sym_db.RegisterMessage(User)

Permission = _reflection.GeneratedProtocolMessageType('Permission', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSION,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.Permission)
  })
_sym_db.RegisterMessage(Permission)

UserSpec = _reflection.GeneratedProtocolMessageType('UserSpec', (_message.Message,), {
  'DESCRIPTOR' : _USERSPEC,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.UserSpec)
  })
_sym_db.RegisterMessage(UserSpec)

UserSettings = _reflection.GeneratedProtocolMessageType('UserSettings', (_message.Message,), {
  'DESCRIPTOR' : _USERSETTINGS,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.UserSettings)
  })
_sym_db.RegisterMessage(UserSettings)

UserQuota = _reflection.GeneratedProtocolMessageType('UserQuota', (_message.Message,), {
  'DESCRIPTOR' : _USERQUOTA,
  '__module__' : 'yandex.cloud.mdb.clickhouse.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.UserQuota)
  })
_sym_db.RegisterMessage(UserQuota)


DESCRIPTOR._options = None
_USERSPEC.fields_by_name['name']._options = None
_USERSPEC.fields_by_name['password']._options = None
_USERSETTINGS.fields_by_name['readonly']._options = None
_USERSETTINGS.fields_by_name['insert_quorum']._options = None
_USERSETTINGS.fields_by_name['connect_timeout']._options = None
_USERSETTINGS.fields_by_name['receive_timeout']._options = None
_USERSETTINGS.fields_by_name['send_timeout']._options = None
_USERSETTINGS.fields_by_name['insert_quorum_timeout']._options = None
_USERSETTINGS.fields_by_name['max_replica_delay_for_distributed_queries']._options = None
_USERSETTINGS.fields_by_name['replication_alter_partitions_sync']._options = None
_USERSETTINGS.fields_by_name['min_count_to_compile']._options = None
_USERSETTINGS.fields_by_name['min_count_to_compile_expression']._options = None
_USERSETTINGS.fields_by_name['max_block_size']._options = None
_USERSETTINGS.fields_by_name['min_insert_block_size_rows']._options = None
_USERSETTINGS.fields_by_name['min_insert_block_size_bytes']._options = None
_USERSETTINGS.fields_by_name['max_insert_block_size']._options = None
_USERSETTINGS.fields_by_name['min_bytes_to_use_direct_io']._options = None
_USERSETTINGS.fields_by_name['merge_tree_max_rows_to_use_cache']._options = None
_USERSETTINGS.fields_by_name['merge_tree_max_bytes_to_use_cache']._options = None
_USERSETTINGS.fields_by_name['merge_tree_min_rows_for_concurrent_read']._options = None
_USERSETTINGS.fields_by_name['merge_tree_min_bytes_for_concurrent_read']._options = None
_USERSETTINGS.fields_by_name['priority']._options = None
_USERSETTINGS.fields_by_name['max_threads']._options = None
_USERSETTINGS.fields_by_name['max_memory_usage']._options = None
_USERSETTINGS.fields_by_name['max_memory_usage_for_user']._options = None
_USERSETTINGS.fields_by_name['max_rows_to_read']._options = None
_USERSETTINGS.fields_by_name['max_bytes_to_read']._options = None
_USERSETTINGS.fields_by_name['max_rows_to_group_by']._options = None
_USERSETTINGS.fields_by_name['max_rows_to_sort']._options = None
_USERSETTINGS.fields_by_name['max_bytes_to_sort']._options = None
_USERSETTINGS.fields_by_name['max_result_rows']._options = None
_USERSETTINGS.fields_by_name['max_result_bytes']._options = None
_USERSETTINGS.fields_by_name['max_rows_in_distinct']._options = None
_USERSETTINGS.fields_by_name['max_bytes_in_distinct']._options = None
_USERSETTINGS.fields_by_name['max_rows_to_transfer']._options = None
_USERSETTINGS.fields_by_name['max_bytes_to_transfer']._options = None
_USERSETTINGS.fields_by_name['max_execution_time']._options = None
_USERSETTINGS.fields_by_name['max_rows_in_set']._options = None
_USERSETTINGS.fields_by_name['max_bytes_in_set']._options = None
_USERSETTINGS.fields_by_name['max_rows_in_join']._options = None
_USERSETTINGS.fields_by_name['max_bytes_in_join']._options = None
_USERSETTINGS.fields_by_name['max_columns_to_read']._options = None
_USERSETTINGS.fields_by_name['max_temporary_columns']._options = None
_USERSETTINGS.fields_by_name['max_temporary_non_const_columns']._options = None
_USERSETTINGS.fields_by_name['max_query_size']._options = None
_USERSETTINGS.fields_by_name['max_ast_depth']._options = None
_USERSETTINGS.fields_by_name['max_ast_elements']._options = None
_USERSETTINGS.fields_by_name['max_expanded_ast_elements']._options = None
_USERSETTINGS.fields_by_name['min_execution_speed']._options = None
_USERSETTINGS.fields_by_name['min_execution_speed_bytes']._options = None
_USERQUOTA.fields_by_name['interval_duration']._options = None
_USERQUOTA.fields_by_name['queries']._options = None
_USERQUOTA.fields_by_name['errors']._options = None
_USERQUOTA.fields_by_name['result_rows']._options = None
_USERQUOTA.fields_by_name['read_rows']._options = None
_USERQUOTA.fields_by_name['execution_time']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/greenplum/v1/host.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.mdb.greenplum.v1 import config_pb2 as yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_config__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/greenplum/v1/host.proto',
  package='yandex.cloud.mdb.greenplum.v1',
  syntax='proto3',
  serialized_options=b'\n!yandex.cloud.api.mdb.greenplum.v1B\003GPHZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(yandex/cloud/mdb/greenplum/v1/host.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a*yandex/cloud/mdb/greenplum/v1/config.proto\x1a\x1dyandex/cloud/validation.proto\"\xb3\x03\n\x04Host\x12\x1a\n\x04name\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x0f\n\x07zone_id\x18\x03 \x01(\t\x12\x36\n\x04type\x18\x04 \x01(\x0e\x32(.yandex.cloud.mdb.greenplum.v1.Host.Type\x12;\n\tresources\x18\x05 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\x12:\n\x06health\x18\x06 \x01(\x0e\x32*.yandex.cloud.mdb.greenplum.v1.Host.Health\x12\x11\n\tsubnet_id\x18\x07 \x01(\t\x12\x18\n\x10\x61ssign_public_ip\x18\x08 \x01(\x08\"B\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06MASTER\x10\x01\x12\x0b\n\x07REPLICA\x10\x02\x12\x0b\n\x07SEGMENT\x10\x03\"H\n\x06Health\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\x12\x0e\n\nUNBALANCED\x10\x04\x42u\n!yandex.cloud.api.mdb.greenplum.v1B\x03GPHZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_config__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])



_HOST_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yandex.cloud.mdb.greenplum.v1.Host.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MASTER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REPLICA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEGMENT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=446,
  serialized_end=512,
)
_sym_db.RegisterEnumDescriptor(_HOST_TYPE)

_HOST_HEALTH = _descriptor.EnumDescriptor(
  name='Health',
  full_name='yandex.cloud.mdb.greenplum.v1.Host.Health',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEAD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEGRADED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNBALANCED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=514,
  serialized_end=586,
)
_sym_db.RegisterEnumDescriptor(_HOST_HEALTH)


_HOST = _descriptor.Descriptor(
  name='Host',
  full_name='yandex.cloud.mdb.greenplum.v1.Host',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.greenplum.v1.Host.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.greenplum.v1.Host.cluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.mdb.greenplum.v1.Host.zone_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.mdb.greenplum.v1.Host.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.greenplum.v1.Host.resources', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health', full_name='yandex.cloud.mdb.greenplum.v1.Host.health', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.mdb.greenplum.v1.Host.subnet_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assign_public_ip', full_name='yandex.cloud.mdb.greenplum.v1.Host.assign_public_ip', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HOST_TYPE,
    _HOST_HEALTH,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=586,
)

_HOST.fields_by_name['type'].enum_type = _HOST_TYPE
_HOST.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_config__pb2._RESOURCES
_HOST.fields_by_name['health'].enum_type = _HOST_HEALTH
_HOST_TYPE.containing_type = _HOST
_HOST_HEALTH.containing_type = _HOST
DESCRIPTOR.message_types_by_name['Host'] = _HOST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Host = _reflection.GeneratedProtocolMessageType('Host', (_message.Message,), {
  'DESCRIPTOR' : _HOST,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.host_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.Host)
  })
_sym_db.RegisterMessage(Host)


DESCRIPTOR._options = None
_HOST.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)
